function LoginUtilities(ScreenService, MessageService, localStorageEngine, ZHPromise) {
    
    /* global Configuration */
    /* global Util */
    
    const self = this;
    
    this.defaultError = function(response) {
        return MessageService.getMessageByCode('product#ERR_UNEXPECTED_ERROR').then(function(defaultMessage) {
            if (response && response.data && response.data.error) {
                let error = response.data.error;
                
                if (self.isJson(error)) {
                    error = JSON.parse(error);
                    
                    const params = error.PARAMS || null;
                    const messageCode = error.CODE || 'ERR_UNEXPECTED_ERROR';
                    
                    if (messageCode == 'INVALID_PASSWORD_MASK') {
                        return self.showInvalidPasswordMaskMessage(messageCode, params);
                    } else {
                        return MessageService.getMessageByCode('product#' + messageCode).then(function (message) {
                            return ScreenService.showMessage(message, 'ERROR', null, params);
                        }).catch(function () {
                            return ScreenService.showMessage(messageCode, 'ERROR', null, params);
                        });
                    }
                } else {
                    var message = Util.isEmptyOrBlank(error) ? defaultMessage : error.split("Exception:").pop();
                    return ScreenService.showMessage(message, 'ERROR');
                }
            } else {
                return ScreenService.showMessage(defaultMessage, 'ERROR');
            }
        });
    };
    
    this.showInvalidPasswordMaskMessage = function(messageCode, params) {
        let messages = '';
        const promises = [];
        
        params.forEach(function(param) {
            if (param && param.EXISTS_MASK && param.INVALID_MASK) {
                let messagePromise = MessageService.getMessageByCode('login#' + param.MESSAGE).then(function(message) {
                    messages += '<li align="left">' + ScreenService.i18n(message, param.PARAMS) + '</li>';
                });
                
                promises.push(messagePromise);
            }
        });
        
        ZHPromise.all(promises).then(function() {
            MessageService.showMessageByCode('product#' + messageCode, { validations: messages }, { type: 'ALERT' });
        });
    };
}

Configuration(function(ContextRegister) {
    ContextRegister.register('LoginUtilities', LoginUtilities);
});
